#!/bin/bash
#
# Adfinis SyGroup AG
# <GitLab Repository URL> (nicht der ganze Pfad)
#
# This scripts eases the creation of new customers.


### Abfragen
echo "Kurzname des Kunden: [a-z] (Weniger als 15 Zeichen)"
read shortname

echo "Kompletter Name des Kunden: [A-Za-z0-9]"
read fullname

### OU für Kunden erstellen
udm container/ou create --set name=$shortname --set description="$fullname" --position ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch

### Funktionsgruppen in der Kunden-OU erstellen
udm groups/group create \
  --set name=$shortname-wiki \
  --set description="Wiki-Funktion für Kunde $fullname" \
  --position "ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
udm groups/group create \
  --set name=$shortname-redmine \
  --set description="Redmine-Funktion für Kunde $fullname" \
  --position "ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
udm groups/group create \
  --set name=$shortname-rhev \
  --set description="RHEV-Funktion für Kunde $fullname" \
  --position "ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
udm groups/group create \
  --set name=$shortname-mon \
  --set description="Monitoring-Funktion für Kunde $fullname" \
  --position "ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
udm groups/group create \
  --set name=$shortname-powerdns \
  --set description="PowerDNS-Funktion für Kunde $fullname" \
  --position "ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
udm groups/group create \
  --set name=$shortname-gitlab \
  --set description="GitLab-Funktion für Kunde $fullname" \
  --position "ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
udm groups/group create \
  --set name=$shortname-sysupport \
  --set description="SySupport-Funktion für Kunde $fullname" \
  --position "ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"


### Admin Benutzer erstellen
password=`pwgen -s 12 1`


### Klammern und ^ um ersten Buchstaben gross zu setzen
adminuser=${shortname^}-admin
udm users/user create \
  --position="ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --set username="$adminuser" \
  --set firstname="Adminuser" \
  --set lastname="$shortname" \
  --set description="Adminuser der Firma $fullname" \
  --set primaryGroup="cn=adsy-customer,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --set password="$password"\
  --set shell="/bin/false"\
  --set CtxCfgTSLogon=0 \
  --policy-reference "cn=adsy-customer-policy,cn=UMC,cn=policies,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"\
  --option samba \
  --option kerberos \
  --option person \
  --option posix \
  --append groups="cn=customers-powerdns,cn=groups,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=customers-redmine,cn=groups,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=customers-gitlab,cn=groups,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=$shortname-wiki,ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=$shortname-redmine,ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=$shortname-rhev,ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=$shortname-mon,ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=$shortname-powerdns,ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=$shortname-gitlab,ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
  --append groups="cn=$shortname-sysupport,ou=$shortname,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" 

echo ""
echo "Folgenden Informationen im AdSy Wiki auf der Startseite des Kunden eintragen:";
echo "Administratorbenutzer: $adminuser"
echo "Administratorpasswort: $password"
echo ""
echo "Weitere Benutzer mit dem Skript create-new-user.sh erstellen."
echo ""

# vim: ai ts=2 sw=2 et sts=2 ft=sh
