#!/bin/bash
#
# Adfinis SyGroup AG
# https://git.adfinis-sygroup.ch/ad-sy/adsy-ldap-manipulation.src
#
# import user from csv

IFS=$'§\n'

cat new-ldap-userlist.csv | while read USERNAME SHORTNAME EMAIL FIRSTNAME LASTNAME PASSWORD FULLNAME TYPE WIKI REDMINE MON RHEV; do
  # Kontrolle ob Kunde existiert
  CONTROL=`univention-ldapsearch -xLLL ou=$SHORTNAME -b ou=$TYPE,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch ou`
  if [ -z "$CONTROL" ]; then
    # OU für Partner/Kunden erstellen
    udm container/ou create \
      --set name=$SHORTNAME \
      --set description="$FULLNAME" \
      --position="ou=$TYPE,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"

    # Funktionsgruppen erstellen falls Kunde
    if [ $TYPE == "customers" ]; then
      # Funktionsgruppen in der Kunden-OU erstellen
      udm groups/group create --set name=$SHORTNAME-wiki --set description="Wiki-Funktion für Kunde $FULLNAME" \
        --position "ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
      udm groups/group create --set name=$SHORTNAME-redmine --set description="Redmine-Funktion für Kunde $FULLNAME" \
        --position "ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
      udm groups/group create --set name=$SHORTNAME-rhev --set description="RHEV-Funktion für Kunde $FULLNAME" \
        --position "ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
      udm groups/group create --set name=$SHORTNAME-mon --set description="Monitoring-Funktion für Kunde $FULLNAME" \
        --position "ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
    fi
  fi

  if [ -z "$PASSWORD" ]; then
    PASSWORD=`pwgen -s 12 1`
    echo "Benutzer: $USERNAME" >> user-passwords.txt
    echo "Passwort: $PASSWORD" >> user-passwords.txt
    echo "" >> user-passwords.txt
  fi

  case "$TYPE" in
    customers)
      udm users/user create \
        --position="ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
        --set username="$USERNAME" \
        --set firstname="$FIRSTNAME" \
        --set lastname="$LASTNAME" \
        --set description="$FIRSTNAME $LASTNAME" \
        --set primaryGroup="cn=adsy-customer,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
        --set password="$PASSWORD"\
        --set mailPrimaryAddress="$EMAIL" \
        --set shell="/bin/false"\
        --policy-reference "cn=adsy-customer-policy,cn=UMC,cn=policies,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"\
        --option samba \
        --option kerberos \
        --option person \
        --option posix

      # Gruppen zuweisen
      if [ $WIKI == 1 ]; then
        udm users/user modify \
          --dn="uid=$USERNAME,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
          --append groups="cn=$SHORTNAME-wiki,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
      fi

      if [ $REDMINE == 1 ]; then
        udm users/user modify \
          --dn="uid=$USERNAME,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
          --append groups="cn=$SHORTNAME-redmine,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
      fi

      if [ $MON == 1 ]; then
        udm users/user modify \
          --dn="uid=$USERNAME,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
          --append groups="cn=$SHORTNAME-mon,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
      fi

      if [ $RHEV == 1 ]; then
        udm users/user modify \
          --dn="uid=$USERNAME,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
          --append groups="cn=$SHORTNAME-rhev,ou=$SHORTNAME,ou=customers,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"
      fi

      ;;

    partner)
      udm users/user create \
        --position="ou=$SHORTNAME,ou=partner,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
        --set username="$USERNAME" \
        --set firstname="$FIRSTNAME" \
        --set lastname="$LASTNAME" \
        --set description="$FIRSTNAME $LASTNAME" \
        --set primaryGroup="cn=adsy-partner,ou=partner,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch" \
        --set password="$PASSWORD"\
        --set mailPrimaryAddress="$EMAIL" \
        --set shell="/bin/false"\
        --policy-reference "cn=adsy-partner-policy,cn=UMC,cn=policies,dc=adsy-ext,dc=becs,dc=adfinis-sygroup,dc=ch"\
        --option samba \
        --option kerberos \
        --option person \
        --option posix
      ;;
  esac
done

# vim: ai ts=2 sw=2 et sts=2 ft=sh
